{% extends 'base.html' %}

{% block content %}
  <form method="post">
    <label for="body_input">Body</label>
    <textarea name="body" id="body_input" class="message" required></textarea>
    <label for="pin_input">PIN</label>
    <input type="password" name="pin" id="pin_input" maxlength="6" size="6" class="pin" required>
    <input type="hidden" name="_csrf_token" value="{{csrf_token}}" />
    <input type="submit" value="Add">
  </form>
{% endblock %}
