.content {
    display: table;
    position: absolute;
    height: 100%;
    width: 100%;
}

.centered {
    display: table-cell;
    vertical-align: middle;
    margin: 0 auto;
    text-align: center;
}

.error {
    font-weight: bold;
    color: red;
}

.message {
    font-size: larger;
    font-family: monospace, monospace;
    border: solid 1px lightgray;
    display: inline-block;
    vertical-align: middle;
    text-align: left;
    padding: 10px;
}

.pin {
    border: solid 1px lightgray;
    padding: 10px;
}
